#ifndef MAEMO5DIALOG_H
#define MAEMO5DIALOG_H

#include <QDialog>

class Maemo5Dialog : public QDialog
{
    Q_OBJECT

public:
    explicit Maemo5Dialog (QWidget *parent = 0) : QDialog(parent) {/* DO NOTHING */}

public slots:
#if defined(Q_WS_MAEMO_5)
    void show ()
    {
        this->setAttribute(Qt::WA_Maemo5PortraitOrientation,
                           this->parentWidget()->width() < this->parentWidget()->height());
        QDialog::show();
    }
#endif
};

#endif // MAEMO5DIALOG_H
